@@ -30,8 +30,8 @@
 
 #include <QtNumeric>
 
+#include <QStringLiteral>
 #include <chrono>
-#include <qstringliteral.h>
 
 using namespace std::literals::chrono_literals;
 using namespace Qt::Literals::StringLiterals;
@@ -181,7 +181,7 @@ void TimerModel::setDefaultAudioLocation(QString location)
     if (m_defaultAudioLocation.path() != location) {
         location = location.replace(QStringLiteral("file://"), QString());
         m_defaultAudioLocation = QUrl::fromLocalFile(location);
-        Q_EMIT defaultAudioLocationChanged();
+        Q_EMIT defaultAudioLocationChanged(defaultAudioLocation());
         save();
     }
 }
